Pyramid Frontend Tools
======================

Scott Torborg - `Cart Logic <http://www.cartlogic.com>`_

``pyramid_frontend`` provides:

* Theme / template handling.
* Theme switching based on the ``request``.
* Theme configuration.
* Theme stacking (one theme can inherit from another).
* Image filtering / serving.
* Asset handling and compilation.
* Uses Mako, PIL, require.js, and LESS.

Contents
========

.. toctree::
    :maxdepth: 2

    quickstart
    configuration
    advanced
    api
    contributing


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
